@@ -74,7 +74,6 @@ my @not_built_in_num = (
     'CURLOPT_SOCKS5_AUTH',
     );
 
-
 #
 # Generate a set of string checks
 #
@@ -206,19 +205,18 @@ print $fh <<HEADER
  *
  ***************************************************************************/
 #include "first.h"
-#include "memdebug.h"
 
 /* This source code is generated by mk-lib1521.pl ! */
 
 struct t1521_testdata {
-  char *blaha;
+  const char *blaha;
 };
 
 #define LO $minlong
 #define HI $maxlong
-#define OFF_LO (curl_off_t) LO
-#define OFF_HI (curl_off_t) $maxofft
-#define OFF_NO (curl_off_t) 0
+#define OFF_LO ((curl_off_t)(LO))
+#define OFF_HI ((curl_off_t)($maxofft))
+#define OFF_NO ((curl_off_t)0)
 
 static size_t writecb(char *buffer, size_t size, size_t nitems,
                       void *outstream)
@@ -347,7 +345,9 @@ static bool bad_neg(int check)
 
 /* macro to check the first setopt of an option which then is allowed to get a
    non-existing function return code back */
-#define present(x) ((x != CURLE_NOT_BUILT_IN) && (x != CURLE_UNKNOWN_OPTION))
+#define present(x)                \\
+  (((x) != CURLE_NOT_BUILT_IN) && \\
+   ((x) != CURLE_UNKNOWN_OPTION))
 
 static CURLcode test_lib1521(const char *URL)
 {
@@ -366,22 +366,22 @@ static CURLcode test_lib1521(const char *URL)
   FILE *stream = stderr;
   struct t1521_testdata object;
   CURLU *curlu = (CURLU *)&object;
-  char *charp;
+  const char *charp;
   long val;
   curl_off_t oval;
   double dval;
   curl_socket_t sockfd;
-  struct curl_certinfo *certinfo;
+  const struct curl_certinfo *certinfo;
   struct curl_tlssessioninfo *tlssession;
   struct curl_blob blob = { CURL_UNCONST("silly"), 5, 0};
-  CURLcode res = CURLE_OK;
+  CURLcode result = CURLE_OK;
   (void)URL;
   global_init(CURL_GLOBAL_ALL);
   easy_init(dep);
   easy_init(curl);
   share = curl_share_init();
   if(!share) {
-    res = CURLE_OUT_OF_MEMORY;
+    result = CURLE_OUT_OF_MEMORY;
     goto test_cleanup;
   }
 
@@ -449,7 +449,10 @@ while(<STDIN>) {
         # the first check for an option
         my $fpref = "${exists}${w2}CURLcode first =\n${w3}curl_easy_setopt(curl, $name,";
         my $ifpresent = "${w2}if(present(first)) {\n";
-        my $pref = "${w3}res = curl_easy_setopt(curl, $name,";
+        my $pref = "${w3}result =\n".
+                   "${w3}  curl_easy_setopt(curl, $name,";
+        my $ignoreset = "${w3}/* set string again to check for leaks */\n".
+            "${w3}(void)curl_easy_setopt(curl, $name,";
         my $i = ' ' x (length($w) + 25);
         my $fcheck = <<MOO
     if(first && present(first)) /* first setopt check only */
@@ -462,8 +465,8 @@ MOO
 MOO
             ;
         my $check = <<MOO
-      if(res)
-        err("$name", res, __LINE__);
+      if(result)
+        err("$name", result, __LINE__);
 MOO
             ;
         my $flongcheckzero = <<MOO
@@ -474,20 +477,20 @@ MOO
             ;
 
         my $longcheck = <<MOO
-      if(res && !bad_long(res, $name))
-        errlong("$name", res, __LINE__);
+      if(result && !bad_long(result, $name))
+        errlong("$name", result, __LINE__);
 MOO
             ;
 
         my $negcheck = <<MOO
-      if(res && bad_neg($name))
-        errneg("$name", res, __LINE__);
+      if(result && bad_neg($name))
+        errneg("$name", result, __LINE__);
 MOO
             ;
 
         my $nullcheck = <<MOO
-      if(res)
-        errnull(\"$name\", res, __LINE__);
+      if(result)
+        errnull(\"$name\", result, __LINE__);
 MOO
             ;
 
@@ -495,6 +498,7 @@ MOO
         if($type eq "CURLOPTTYPE_STRINGPOINT") {
             print $fh "${fpref} \"string\");\n$fstringcheck";
             print $fh "$ifpresent";
+            print $fh "${ignoreset} \"\");\n";
             print $fh "${pref} NULL);\n$nullcheck";
         }
         elsif(($type eq "CURLOPTTYPE_LONG") ||
@@ -588,8 +592,8 @@ MOO
     elsif($infomode &&
           ($_ =~ /^CURLINFO_([^ ]*) *= *CURLINFO_([^ ]*)/)) {
        my ($info, $type)=($1, $2);
-       my $c = "  res = curl_easy_getinfo(curl, CURLINFO_$info,";
-       my $check = "  if(res)\n    t1521_geterr(\"$info\", res, __LINE__);\n";
+       my $c = "  result = curl_easy_getinfo(curl, CURLINFO_$info,";
+       my $check = "  if(result)\n    t1521_geterr(\"$info\", result, __LINE__);\n";
        if($type eq "STRING") {
          print $fh "$c &charp);\n$check";
        }
@@ -627,21 +631,20 @@ MOO
     }
 }
 
-
 print $fh <<FOOTER
 
   /* NOLINTNEXTLINE(clang-analyzer-optin.core.EnumCastOutOfRange) */
   curl_easy_setopt(curl, (CURLoption)1, 0L);
-  res = CURLE_OK;
+  result = CURLE_OK;
 test_cleanup:
   curl_easy_cleanup(curl);
   curl_easy_cleanup(dep);
   curl_share_cleanup(share);
   curl_global_cleanup();
 
-  if(!res)
+  if(!result)
     puts("ok");
-  return res;
+  return result;
 }
 FOOTER
     ;
